LintAnalysisConfig class

Represents converted lint config which contains parsed entities.

Constructors

LintAnalysisConfig(Iterable<Glob> globalExcludes, Iterable<Rule> codeRules, Iterable<Glob> rulesExcludes, Iterable<Pattern> antiPatterns, Iterable<Metric<num>> classesMetrics, Iterable<Metric<num>> fileMetrics, Iterable<Metric<num>> methodsMetrics, Iterable<Glob> metricsExcludes, Map<String, Object> metricsConfig, String rootFolder, String? analysisOptionsPath)
const

Properties

analysisOptionsPath → String?
final
antiPatterns → Iterable<Pattern>
final
classesMetrics → Iterable<Metric<num>>
final
codeRules → Iterable<Rule>
final
fileMetrics → Iterable<Metric<num>>
final
globalExcludes → Iterable<Glob>
final
hashCode → int
The hash code for this object.
no setterinherited
methodsMetrics → Iterable<Metric<num>>
final
metricsConfig → Map<String, Object>
final
metricsExcludes → Iterable<Glob>
final
rootFolder → String
final
rulesExcludes → Iterable<Glob>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited