UnusedFilesAnalysisConfig class

Represents converted unused files config which contains parsed entities.

Constructors

UnusedFilesAnalysisConfig(Iterable<Glob> globalExcludes, {required bool isMonorepo})
const

Properties

globalExcludes → Iterable<Glob>
final
hashCode → int
The hash code for this object.
no setterinherited
isMonorepo → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited