UnusedFilesConfig class

Represents raw unused files config which can be merged with other raw configs.

Constructors

UnusedFilesConfig({required Iterable<String> excludePatterns, required Iterable<String> analyzerExcludePatterns, required bool isMonorepo, required bool shouldPrintConfig})
const
UnusedFilesConfig.fromAnalysisOptions(AnalysisOptions options)
Creates the config from analysis options.
factory
UnusedFilesConfig.fromArgs(Iterable<String> excludePatterns, {required bool isMonorepo, required bool shouldPrintConfig})
Creates the config from cli args.
factory

Properties

analyzerExcludePatterns → Iterable<String>
final
excludePatterns → Iterable<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isMonorepo → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shouldPrintConfig → bool
final

Methods

merge(UnusedFilesConfig overrides) → UnusedFilesConfig
Merges two configs into a single one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited